pub struct Counter { /* private fields */ }Expand description
A counter is a cumulative metric that represents a single monotonically increasing counter whose value can only increase or be reset to zero.
Implementations